Retidy, removing align=left from headings and empty paragraphs

This commit is contained in:
James Gregory 2013-12-30 15:37:13 +11:00
commit a96a114403
362 changed files with 8472 additions and 5040 deletions

View file

@ -1,5 +1,4 @@
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
@ -19,17 +18,21 @@
<center>
<table border="1">
<tr>
<td><a href="44-06.html">Previous</a></td>
<td>
<a href="44-06.html">Previous</a>
</td>
<td><a href="index.html">Table of Contents</a></td>
<td>
<a href="index.html">Table of Contents</a>
</td>
<td><a href="45-02.html">Next</a></td>
<td>
<a href="45-02.html">Next</a>
</td>
</tr>
</table>
</center>
<p><br /></p>
<h2 id="Heading1">Chapter 45<br />
Dog Hair and Dirty Rectangles</h2>
@ -59,16 +62,20 @@
<p>As slow as 30 or even 10 cycles is for an <b>OUT</b>, one could only wish that VGA I/O were actually that fast. The fastest measured <b>OUT</b> to a VGA in Table 45.1 is 26 cycles, and the slowest is 126&mdash;this for an operation that&rsquo;s <i>supposed</i> to take 10 cycles. To put this in context, <b>MUL</b> takes only 13 to 42 cycles, and a normal <b>MOV</b> to or from system memory takes exactly one cycle on the 486. In short, <b>OUT</b>s to VGAs are as much as 100 times slower than normal memory accesses, and are generally two to four times slower than even display memory accesses, although there are exceptions.</p>
<p><br /></p>
<center>
<table border="1">
<tr>
<td><a href="44-06.html">Previous</a></td>
<td>
<a href="44-06.html">Previous</a>
</td>
<td><a href="index.html">Table of Contents</a></td>
<td>
<a href="index.html">Table of Contents</a>
</td>
<td><a href="45-02.html">Next</a></td>
<td>
<a href="45-02.html">Next</a>
</td>
</tr>
</table>
</center>